import{S as c}from"./Sidebar.8770268a.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.e6bb4a9d.js";import{G as l,H as u,I as b}from"./icons.faa6dbaa.js";import{d,eA as f,J as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.300f3e96.js";import{a as w}from"./asyncComputed.6561fe78.js";import"./router.fdc19966.js";import{O as z}from"./organization.ffaf9442.js";import"./index.92fda3db.js";import{B as h}from"./BaseLayout.d72db165.js";import"./Tooltip.98a77259.js";import"./logo.084e5d7c.js";import"./index.b12dda90.js";import"./Title.f9e3ac72.js";import"./index.c74452a7.js";import"./index.5dabecc6.js";import"./index.4c022ec6.js";import"./gateway.d0550bff.js";import"./activeRecord.6e31bcda.js";import"./pubsub.f4c4af7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="01a0b56f-856c-45b6-a71c-7e992b2e43ac",e._sentryDebugIdIdentifier="sentry-dbid-01a0b56f-856c-45b6-a71c-7e992b2e43ac")}catch{}})();const q=d({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:u,path:"members"},{name:"Billing",icon:b,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.358890b2.js.map
