import"./outputWidgets.300f3e96.js";import{M as r}from"./Title.f9e3ac72.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3480f9e3-93b7-4e9e-b6cd-069b32b173c7",e._sentryDebugIdIdentifier="sentry-dbid-3480f9e3-93b7-4e9e-b6cd-069b32b173c7")}catch{}})();function o(e){switch(typeof e){case"object":return Object.entries(e).map(([t,n])=>({title:t,key:t,children:o(n)}));default:return[{title:e,key:e}]}}function s(e){return new Promise(t=>{r.confirm({title:e,onOk:()=>t(!0),onCancel:()=>t(!1)})})}export{s as a,o as t};
//# sourceMappingURL=ant-design.e9641753.js.map
