import{R as t}from"./Title.f9e3ac72.js";import{F as n}from"./outputWidgets.300f3e96.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="904f77a2-d969-4002-b897-bf16d5396ad0",e._sentryDebugIdIdentifier="sentry-dbid-904f77a2-d969-4002-b897-bf16d5396ad0")}catch{}})();const s=n(t);export{s as A};
//# sourceMappingURL=index.0deb6cbe.js.map
