import"./outputWidgets.300f3e96.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="16a67ac9-d529-440e-9d58-ff2cad36b216",e._sentryDebugIdIdentifier="sentry-dbid-16a67ac9-d529-440e-9d58-ff2cad36b216")}catch{}})();function d(e){return e.charAt(0).toUpperCase()+e.slice(1)}function s(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{d as c,s as n};
//# sourceMappingURL=string.5f3859a9.js.map
