import{d as b,ez as g,eA as v,r as k,b as r,c as s,w as a,u as e,f as u,ew as n}from"./outputWidgets.300f3e96.js";import{S as h,L as w}from"./SmartConsole.77f4105d.js";import{a as x}from"./asyncComputed.6561fe78.js";import{H as B}from"./hooks.33df6109.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.696d43cd.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.e478a443.js";import{B as I}from"./BaseLayout.d72db165.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.001a2105.js";import{c as A}from"./index.5dabecc6.js";import{A as _,T as D}from"./TabPane.17809989.js";import"./forms.e8d7c389.js";import"./activeRecord.6e31bcda.js";import"./pubsub.f4c4af7d.js";import"./dashes.84ffed24.js";import"./index.4c022ec6.js";import"./jobs.5cb7afa3.js";import"./workspaces.dcbbc90b.js";import"./url.f346bb44.js";import"./icons.faa6dbaa.js";import"./Title.f9e3ac72.js";import"./index.0deb6cbe.js";import"./uuid.bbce5058.js";import"./ant-design.e9641753.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.70794c6d.js";import"./RunButton.vue_vue_type_script_setup_true_lang.0f7e6866.js";import"./index.f8e501c5.js";import"./index.b49fb559.js";import"./CollapsePanel.11538760.js";import"./index.c74452a7.js";import"./index.b81953c5.js";import"./index.f69106a7.js";import"./Form.e5ad8df8.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="611e0b45-3f2a-4f48-bebf-48333a32e58c",i._sentryDebugIdIdentifier="sentry-dbid-611e0b45-3f2a-4f48-bebf-48333a32e58c")}catch{}})();const le=b({__name:"HookEditor",setup(i){const m=g(),l=v(),f=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(l.params.hookPath)),c=w.create();return(R,d)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(A),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:f,hook:e(t),"log-service":e(c)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(c),onRestart:(p=f.value)==null?void 0:p.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{le as default};
//# sourceMappingURL=HookEditor.55f0519d.js.map
