import{x as o,a,b as i,c,g as p,h as d,_,i as u,T as l,j as f,P as h,C as b,M as m,s as y,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.300f3e96.js";import{u as k}from"./index.5c5a7853.js";import"./pubsub.f4c4af7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="74ec77cb-45fb-4d7c-9ef4-0348b07758a2",e._sentryDebugIdIdentifier="sentry-dbid-74ec77cb-45fb-4d7c-9ef4-0348b07758a2")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.f33667ac.js"),["assets/Player.f33667ac.js","assets/index.4c022ec6.js","assets/outputWidgets.300f3e96.js","assets/outputWidgets.f6e466ca.css","assets/uuid.bbce5058.js","assets/broker.ee0dbdd1.js","assets/index.5c5a7853.js","assets/pubsub.f4c4af7d.js","assets/executeJs.e9a0877c.js","assets/icons.faa6dbaa.js","assets/CircularLoading.832063ba.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.b0e379bf.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.a22d9e96.js","assets/Steps.998aa76d.css","assets/executeJs.ee59d5a5.css","assets/WidgetsFrame.5232fd96.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.98c0f219.js","assets/broker.1fe265d9.css","assets/DashPlayer.0bdcc00d.js","assets/geometryUtils.9544e30b.js","assets/DashPlayer.b0953bcd.css","assets/asyncComputed.6561fe78.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});l.init(),f(e,n),P.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",m),e.component("Message",y),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.0f8f20df.js.map
