import{d as g,ez as v,eA as k,r as b,b as r,c as s,w as a,u as e,f as u,ew as n}from"./outputWidgets.300f3e96.js";import{S as w,L as j}from"./SmartConsole.77f4105d.js";import{a as x}from"./asyncComputed.6561fe78.js";import{J as I}from"./jobs.5cb7afa3.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.696d43cd.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.e478a443.js";import{B as S}from"./BaseLayout.d72db165.js";import{_ as T,a as A}from"./JobSettings.vue_vue_type_script_setup_true_lang.41e8e845.js";import{c as D}from"./index.5dabecc6.js";import{A as _,T as R}from"./TabPane.17809989.js";import"./forms.e8d7c389.js";import"./activeRecord.6e31bcda.js";import"./pubsub.f4c4af7d.js";import"./dashes.84ffed24.js";import"./index.4c022ec6.js";import"./hooks.33df6109.js";import"./workspaces.dcbbc90b.js";import"./url.f346bb44.js";import"./icons.faa6dbaa.js";import"./Title.f9e3ac72.js";import"./index.0deb6cbe.js";import"./uuid.bbce5058.js";import"./ant-design.e9641753.js";import"./RunButton.vue_vue_type_script_setup_true_lang.0f7e6866.js";import"./index.6d2fbde9.js";import"./index.f69106a7.js";import"./dayjs.23074eca.js";import"./Form.e5ad8df8.js";import"./index.c74452a7.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="30045fb0-62ad-482b-831c-36f58be10e00",i._sentryDebugIdIdentifier="sentry-dbid-30045fb0-62ad-482b-831c-36f58be10e00")}catch{}})();const me=g({__name:"JobEditor",setup(i){const m=v(),l=k(),f=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=x(()=>I.get(l.params.jobId)),c=j.create();return($,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:f,job:e(t),"log-service":e(c)},null,8,["job","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(A,{key:1,job:e(t)},null,8,["job"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(w,{key:0,runtime:"forms","log-service":e(c),onRestart:(p=f.value)==null?void 0:p.test},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{me as default};
//# sourceMappingURL=JobEditor.0056bde0.js.map
