import"./outputWidgets.300f3e96.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="64de1b97-b310-4b7b-8d1e-571cfda5eeeb",e._sentryDebugIdIdentifier="sentry-dbid-64de1b97-b310-4b7b-8d1e-571cfda5eeeb")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.f346bb44.js.map
