import{d as f,ez as y,J as b,b as D,c as w,u as g}from"./outputWidgets.300f3e96.js";import{e as _,a as C,b as k}from"./icons.faa6dbaa.js";import{a as v}from"./asyncComputed.6561fe78.js";import{D as l}from"./dashes.84ffed24.js";import{C as x}from"./CrudView.0d50f6ef.js";import{a as I}from"./ant-design.e9641753.js";import"./activeRecord.6e31bcda.js";import"./pubsub.f4c4af7d.js";import"./index.4c022ec6.js";import"./index.b12dda90.js";import"./Title.f9e3ac72.js";import"./Form.e5ad8df8.js";import"./router.fdc19966.js";import"./url.f346bb44.js";import"./index.f69106a7.js";import"./index.0deb6cbe.js";import"./index.b49fb559.js";import"./index.c74452a7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[s]="b8f66536-586c-4a10-b4f5-9fd8d070238e",o._sentryDebugIdIdentifier="sentry-dbid-b8f66536-586c-4a10-b4f5-9fd8d070238e")}catch{}})();const q=f({__name:"Dashes",setup(o){const s=y(),{loading:r,result:n,refetch:d}=v(()=>l.list()),c=({key:e})=>s.push({name:"dashEditor",params:{dashPath:e}}),p=async({key:e})=>{var a,t;await((t=(a=n.value)==null?void 0:a.find(i=>i.path===e))==null?void 0:t.duplicate()),d()},u=async()=>{const e=await l.create();c({key:e.path})},m=async({key:e})=>{var a,t;await I("Are you sure you want to delete this dash?")&&(await((t=(a=n.value)==null?void 0:a.find(i=>i.path===e))==null?void 0:t.delete()),d())},h=b(()=>{var e,a;return{columns:[{name:"Dash Name"},{name:"Path"},{name:"Actions",align:"right"}],rows:(a=(e=n.value)==null?void 0:e.map(t=>({key:t.path,cells:[{text:t.title,link:`/_editor/dash/${encodeURIComponent(t.path)}`},{text:t.path},{text:"",actions:[{icon:_,label:"Edit Dash",onClick:c},{icon:C,label:"Duplicate",onClick:p},{icon:k,label:"Delete",onClick:m,dangerous:!0}]}]})))!=null?a:[]}});return(e,a)=>(D(),w(x,{loading:g(r),title:"Python Dashes",description:"Create a dashboard page with charts and inputs interacting with your python code.","create-button-text":"Create Dash","empty-title":"No dashes here yet","video-url":"https://www.youtube.com/embed/oYMptrk7QNE",table:h.value,"entity-name":"Dash",onCreate:u},null,8,["loading","table"]))}});export{q as default};
//# sourceMappingURL=Dashes.200ac5e5.js.map
