import{cG as n}from"./outputWidgets.300f3e96.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="eafa43ba-2c2e-487c-b532-569c3d7972ba",e._sentryDebugIdIdentifier="sentry-dbid-eafa43ba-2c2e-487c-b532-569c3d7972ba")}catch{}})();const d=(e,r)=>{n.error({message:e,description:r})};export{d as p};
//# sourceMappingURL=popupNotifcation.b2f4fa0a.js.map
