import{v as a}from"./icons.faa6dbaa.js";import{d as r,a as c,b as i,eu as d,f as _,u as f,aJ as l,x as u}from"./outputWidgets.300f3e96.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e6b6f305-0dbe-4817-b331-e798f3bc0452",e._sentryDebugIdIdentifier="sentry-dbid-e6b6f305-0dbe-4817-b331-e798f3bc0452")}catch{}})();const b=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:f(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(b,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.1a50841b.js.map
