import{d as r,r as f,o as c,eQ as u,b as y,c as p,w as s,f as b,aJ as g,eC as m,eO as w,u as i,c4 as k,eW as _}from"./outputWidgets.300f3e96.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="be9cd37f-1d16-466a-9d6b-4298f986d272",e._sentryDebugIdIdentifier="sentry-dbid-be9cd37f-1d16-466a-9d6b-4298f986d272")}catch{}})();const B=r({__name:"ActionButton",props:{action:{},displayName:{},loading:{type:Boolean}},emits:["click"],setup(e,{emit:n}){const o=e,a=f(null);return c(()=>{a.value&&o.action.setElement(a.value),u.addAction(o.action)}),(d,t)=>(y(),p(i(_),null,{default:s(()=>[b(i(k),{ref_key:"element",ref:a,class:"next-button",loading:d.loading,onClick:t[0]||(t[0]=l=>n("click")),onKeydown:t[1]||(t[1]=w(l=>n("click"),["enter"]))},{default:s(()=>[g(m(d.displayName),1)]),_:1},8,["loading"])]),_:1}))}});export{B as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.98c0f219.js.map
