import{d as u,eA as b,J as f,b as y,c as g,u as _}from"./outputWidgets.300f3e96.js";import{a as w}from"./asyncComputed.6561fe78.js";import"./router.fdc19966.js";import{M as n}from"./member.64565058.js";import"./index.92fda3db.js";import{C as I}from"./CrudView.0d50f6ef.js";import"./Title.f9e3ac72.js";import"./index.4c022ec6.js";import"./gateway.d0550bff.js";import"./activeRecord.6e31bcda.js";import"./pubsub.f4c4af7d.js";import"./icons.faa6dbaa.js";import"./index.b12dda90.js";import"./Form.e5ad8df8.js";import"./url.f346bb44.js";import"./index.f69106a7.js";import"./index.0deb6cbe.js";import"./index.b49fb559.js";import"./index.c74452a7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="fcee364d-a3ed-46a9-835b-89621485a2a6",e._sentryDebugIdIdentifier="sentry-dbid-fcee364d-a3ed-46a9-835b-89621485a2a6")}catch{}})();const F=u({__name:"Members",setup(e){const a=b().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(a,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(a)),c=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{F as default};
//# sourceMappingURL=Members.3d89ab88.js.map
