import{x as t,b as d,eu as s}from"./outputWidgets.300f3e96.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="5dbba004-6a41-42a0-a4fd-1d17ddf3c007",e._sentryDebugIdIdentifier="sentry-dbid-5dbba004-6a41-42a0-a4fd-1d17ddf3c007")}catch{}})();const a={},o={class:"organization-settings"};function r(e,n){return d(),s("div",o,"Organization settings")}const f=t(a,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.aa5c3032.js.map
